This is an automated email from the ASF dual-hosted git repository.

morningman pushed a commit to branch branch-2.1
in repository https://gitbox.apache.org/repos/asf/doris.git


The following commit(s) were added to refs/heads/branch-2.1 by this push:
     new 156a2e336e5 branch-2.1: [hotfix](external) Fixed External meta replay 
check (#47931)
156a2e336e5 is described below

commit 156a2e336e5c680011a167eac415cb74efe4bda0
Author: zy-kkk <zhongy...@gmail.com>
AuthorDate: Fri Feb 14 20:34:51 2025 +0800

    branch-2.1: [hotfix](external) Fixed External meta replay check (#47931)
    
    cherry-pick from #47928
---
 .../main/java/org/apache/doris/datasource/ExternalDatabase.java   | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git 
a/fe/fe-core/src/main/java/org/apache/doris/datasource/ExternalDatabase.java 
b/fe/fe-core/src/main/java/org/apache/doris/datasource/ExternalDatabase.java
index a8e527bbc2a..44c7ae961f3 100644
--- a/fe/fe-core/src/main/java/org/apache/doris/datasource/ExternalDatabase.java
+++ b/fe/fe-core/src/main/java/org/apache/doris/datasource/ExternalDatabase.java
@@ -240,8 +240,8 @@ public abstract class ExternalDatabase<T extends 
ExternalTable>
             LOG.info("Synchronized table (create): [Name: {}, ID: {}, Remote 
Name: {}]",
                     table.getName(), table.getId(), 
log.getRemoteTableNames().get(i));
         }
-        // Check whether the remoteName and db Tbl db in idToTbl is empty
-        for (T table : idToTbl.values()) {
+        // Check whether the remoteName and db Tbl db in tmpIdToTbl is empty
+        for (T table : tmpIdToTbl.values()) {
             if (Strings.isNullOrEmpty(table.getRemoteName())
                     || table.getDb() == null) {
                 LOG.info("Table [{}] remoteName or database is empty, mark as 
uninitialized",
@@ -673,8 +673,8 @@ public abstract class ExternalDatabase<T extends 
ExternalTable>
                         ((ExternalTable) obj).getName());
             }
         }
-        // Check whether the remoteName and db Tbl db in idToTbl is empty
-        for (T table : idToTbl.values()) {
+        // Check whether the remoteName and db Tbl db in tmpIdToTbl is empty
+        for (T table : tmpIdToTbl.values()) {
             if (Strings.isNullOrEmpty(table.getRemoteName())
                     || table.getDb() == null) {
                 initialized = false;


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscr...@doris.apache.org
For additional commands, e-mail: commits-h...@doris.apache.org

Reply via email to